import fs = require('fs');
import glob = require('glob');
import path = require('path');
import { Language } from './language';
import { removeComments } from './removeComments';

let indexPath = path.resolve(path.join(__dirname, '../snippets.jsonc'));
let index;

/**
 * Reloads the snippets index.
 */
export function reload() {
	let contents: string = fs.readFileSync(indexPath).toString();
	index = JSON.parse(removeComments(contents));
}

/**
 * Gets a language by name.
 * @param name name of the Language
 * @returns the associated Language object
 */
export function getLanguage(name: string): Language {
	if (!index)
		reload();

	for (let item of index) {
		if (item.name.toLowerCase() === name.toLowerCase()) {
			return new Language(item.name, item.short, glob.sync(item.path, {
				cwd: path.resolve(path.join(__dirname, '..'))
			}));
		}
	}
}

/**
 * A list of language names defined in snippets.jsonc
 * @returns list of languages
 */
 export function getLanguageNames(): string[] {
	if (!index)
		reload();

	let languages = [];

	for (let item of index) {
		languages.push(item.name);
	}

	return languages;
}

/**
 * Gets a list of languages defined in snippets.jsonc
 * @returns list of languages
 */
 export function getLanguages(): Language[] {
	if (!index)
		reload();

	let languages = [];

	for (let item of index) {
		languages.push(getLanguage(item.name));
	}

	return languages;
}

export * from './language';
export * from './snippet';